@@ -21,12 +21,12 @@
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
-ANTHY_PC= '@ANTHY_PC@'
+ANTHY_PC= 'anthy'
 PKGDATADIR = '/usr/share/ibus-anthy'
 LIBEXECDIR = '/usr/lib/ibus'
 LOCALEDIR = '/usr/share/locale'
 LAYOUT = 'jp'
 SYMBOL_CHAR = chr(0x3042)
 ICON_PREFERENCE = 'preferences-desktop'
-VERSION = '1.5.11'
+VERSION = '1.5.16'
 DEBUG = False
